@@ -245,7 +245,7 @@ def writeTables(conf):
 	paths = conf['paths']
 	batches = conf['batches']
 	save_archive = conf['save_archive']
-	from_archive = conf[is_text]
+	from_archive = conf['is_text']
 	if warn == False:
 		warnings.filterwarnings("ignore")
 	start_time = time.time()
@@ -407,7 +407,7 @@ def writeFees(conf):
 	paths = conf['paths']
 	contents = conf['contents']
 	batches = conf['batches']
-	from_archive = conf[is_text]
+	from_archive = conf['is_text']
 	if warn == False:
 		warnings.filterwarnings("ignore")
 	start_time = time.time()
@@ -766,7 +766,7 @@ def getFeeSheet(text: str, cnum: str):
 		amtholdrows = amtholdrows.map(lambda x: x.split(" ")[0].strip() if " " in x else x)
 		istotalrow = fees.map(lambda x: False if bool(re.search(r'(ACTIVE)',x)) else True)
 		try:
-			adminfeerows = pd.Series(actives).str.strip().split(" ")[1].strip()
+			adminfeerows = pd.Series(actives).str.strip().str.split(" ")[1].strip()
 		except IndexError:
 			adminfeerows = []
 		
@@ -775,7 +775,7 @@ def getFeeSheet(text: str, cnum: str):
 			'CaseNumber': cnum,
 			'Total': '',
 			'FeeStatus': 'ACTIVE',
-			'AdminFee': adminfeerows.tolist()
+			'AdminFee': adminfeerows.tolist(),
 			'Code': coderows.tolist(),
 			'Payor': payorrows.tolist(),
 			'AmtDue': amtduerows.tolist(),
